
CONNECT TO rfidic;

------------------------------------------------
-- DDL Statements for table "SERIALID"."ENCODINGTYPE"
------------------------------------------------
 

CREATE TABLE "SERIALID"."ENCODINGTYPE"  (
		  "ENCODING_ID" INTEGER NOT NULL , 
		  "ENCODING_NAME" VARCHAR(15) NOT NULL )   
		 IN "USERSPACE1" ; 

INSERT INTO SERIALID.ENCODINGTYPE VALUES(0,'SGTIN-96');
INSERT INTO SERIALID.ENCODINGTYPE VALUES(0,'AI(01)+AI(21)');
INSERT INTO SERIALID.ENCODINGTYPE VALUES(1,'SSCC-96');
INSERT INTO SERIALID.ENCODINGTYPE VALUES(1,'SSCC-18');

------------------------------------------------
-- DDL Statements for table "SERIALID"."SID_RESOURCE"
------------------------------------------------
 

CREATE TABLE "SERIALID"."SID_RESOURCE"  (
		  "RESOURCE_ID" INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +2147483647  
		    NO CYCLE  
		    NO CACHE  
		    NO ORDER ) , 
		  "RESOURCE_IDENTIFIER" VARCHAR(50) NOT NULL , 
		  "ENCODING_TYPE" INTEGER NOT NULL , 
		  "BLOCK_SIZE" BIGINT NOT NULL , 
		  "THRESHOLD" INTEGER NOT NULL , 
		  "SERIALID_LENGTH" INTEGER NOT NULL , 
		  "NUMBER_SPACE_MULTIPLIER" INTEGER NOT NULL , 
		  "STATE" INTEGER NOT NULL )   
		 IN "USERSPACE1" ; 


-- DDL Statements for primary key on Table "SERIALID"."SID_RESOURCE"

ALTER TABLE "SERIALID"."SID_RESOURCE" 
	ADD CONSTRAINT "PK_RESOURCE_ID" PRIMARY KEY
		("RESOURCE_ID");


-- DDL Statements for unique constraints on Table "SERIALID"."SID_RESOURCE"


ALTER TABLE "SERIALID"."SID_RESOURCE" 
	ADD CONSTRAINT "UK_RES_ENCODING" UNIQUE
		("RESOURCE_IDENTIFIER",
		 "ENCODING_TYPE");

------------------------------------------------
-- DDL Statements for table "SERIALID"."SERIALID_INVENTORY"
------------------------------------------------
 

CREATE TABLE "SERIALID"."SERIALID_INVENTORY"  (
		  "RESOURCE_ID" INTEGER NOT NULL , 
		  "BLOCK_ID" INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +2147483647  
		    NO CYCLE  
		    NO CACHE  
		    NO ORDER ) , 
		  "LOWER_LIMIT" BIGINT NOT NULL , 
		  "UPPER_LIMIT" BIGINT NOT NULL , 
		  "AVAILABLE" BIGINT NOT NULL , 
		  "BLOCK_TYPE" VARCHAR(10) NOT NULL )   
		 IN "USERSPACE1" ; 


-- DDL Statements for primary key on Table "SERIALID"."SERIALID_INVENTORY"

ALTER TABLE "SERIALID"."SERIALID_INVENTORY" 
	ADD CONSTRAINT "PK_BLOCK_ID" PRIMARY KEY
		("BLOCK_ID");


------------------------------------------------
-- DDL Statements for table "SERIALID"."REQUEST"
------------------------------------------------
 

CREATE TABLE "SERIALID"."REQUEST"  (
		  "REQUEST_ID" BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +9223372036854775807  
		    NO CYCLE  
		    NO CACHE  
		    NO ORDER ) , 
		  "REQUEST_TIMESTAMP" BIGINT NOT NULL , 
		  "REQUEST_SOURCE" VARCHAR(10) , 
		  "QUANTITY" BIGINT , 
		  "STATE" INTEGER , 
		  "RESOURCE_ID" INTEGER , 
		  "LOWER_LIMIT" BIGINT , 
		  "UPPER_LIMIT" BIGINT , 
		  "REQUEST_TYPE" VARCHAR(10) )   
		 IN "USERSPACE1" ; 


-- DDL Statements for primary key on Table "SERIALID"."REQUEST"

ALTER TABLE "SERIALID"."REQUEST" 
	ADD CONSTRAINT "PK_REQUEST_ID" PRIMARY KEY
		("REQUEST_ID");

-- DDL Statements for foreign keys on Table "SERIALID"."REQUEST"

ALTER TABLE "SERIALID"."REQUEST" 
	ADD CONSTRAINT "FK_RESOURCE_ID2" FOREIGN KEY
		("RESOURCE_ID")
	REFERENCES "SERIALID"."SID_RESOURCE"
		("RESOURCE_ID")
	ON DELETE NO ACTION
	ON UPDATE NO ACTION
	ENFORCED
	ENABLE QUERY OPTIMIZATION;


-- INSERT A DUMMY REQUEST
INSERT INTO SERIALID.REQUEST(REQUEST_TIMESTAMP,REQUEST_SOURCE,QUANTITY) VALUES(123,'DUMMY',0);

------------------------------------------------
-- DDL Statements for table "SERIALID"."SERIAL_ID"
------------------------------------------------

CREATE TABLE "SERIALID"."SERIAL_ID"  (
		  "RESOURCE_ID" INTEGER NOT NULL , 
		  "SERIAL_ID" BIGINT NOT NULL , 
		  "STATUS" INTEGER NOT NULL WITH DEFAULT 0 , 
		  "REQUEST_ID" BIGINT NOT NULL WITH DEFAULT 1 )   
		 IN "USERSPACE1" ; 


-- DDL Statements for indexes on Table "SERIALID"."SERIAL_ID"

CREATE INDEX "SERIALID"."RID_SID" ON "SERIALID"."SERIAL_ID" 
		("SERIAL_ID" ASC,
		 "RESOURCE_ID" ASC,
		 "REQUEST_ID" ASC)
		PCTFREE 10 MINPCTUSED 10
ALLOW REVERSE SCANS;


-- DDL Statements for foreign keys on Table "SERIALID"."SERIALID_INVENTORY"

ALTER TABLE "SERIALID"."SERIALID_INVENTORY" 
	ADD CONSTRAINT "FK_RESOURCE_ID" FOREIGN KEY
		("RESOURCE_ID")
	REFERENCES "SERIALID"."SID_RESOURCE"
		("RESOURCE_ID")
	ON DELETE NO ACTION
	ON UPDATE NO ACTION
	ENFORCED
	ENABLE QUERY OPTIMIZATION;


------------------------------------------------
-- DDL Statements for table "SERIALID"."EVENTSTORE"
------------------------------------------------
 

CREATE TABLE "SERIALID"."EVENTSTORE"  (
		  "EVENT_ID" BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY (  
		    START WITH +1  
		    INCREMENT BY +1  
		    MINVALUE +1  
		    MAXVALUE +9223372036854775807  
		    NO CYCLE  
		    NO CACHE  
		    NO ORDER ) , 
		  "EVENTXML" CLOB(1048576) LOGGED NOT COMPACT NOT NULL )   
		 IN "USERSPACE1" ; 


-- DDL Statements for primary key on Table "SERIALID"."EVENTSTORE"

ALTER TABLE "SERIALID"."EVENTSTORE" 
	ADD CONSTRAINT "PK_EVENT_ID" PRIMARY KEY
		("EVENT_ID");


COMMIT WORK;
CONNECT RESET;
TERMINATE;
;