#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title:	configPort.sh
##   Description: Updates the /etc/services with the port information of
##		  Informix and MQ
##		
##
#############################################################################


# determine where script was called from
script_location=`dirname $0 2>/dev/null`
if [ -z "$script_location" ];then
	script_location="."
fi

version=v1.1

# determine RFIDIC_HOME and source the rfidic-env.sh here 
if  [ -f $script_location"/../etc/RFIDICServer.xml" ]; then
	RFIDIC_HOME="`( cd \"${script_location}"/.."\" && pwd )`"
	echo "RFIDIC_HOME=$RFIDIC_HOME"
elif [ -n "$RFIDIC_HOME" ]; then
	echo "RFIDIC_HOME=$RFIDIC_HOME"
else
	RFIDIC_HOME=/opt/ibm/WebSphere/RFIDIC$version
fi

if [ -d $RFIDIC_HOME ] 
then
	. $RFIDIC_HOME/bin/rfidic-env.sh> /dev/null
else
	# Use the 'file' command to return the 'cannot open directory' message in the 
	# current locale.  RFIDIC messages are available only after setting the environment.
 	file $RFIDIC_HOME
 	exit -1
fi

ifxport=$IFX_PORT_NUMBER
mqport=$MQ_LSR_PORT

setIFXPort()
{
	if `grep $INFORMIXPORT /etc/services>/dev/null`
	then
		ifxport=`grep $INFORMIXPORT /etc/services|awk '{print(substr($2,1,index($2,"/")-1))}'`
		rfidic-get-message.sh RFID05024I "$ifxport"
	else
		while `grep $ifxport /etc/services>/dev/null`
		do
			rfidic-get-message.sh RFID05025I "$ifxport"
			let ifxport=ifxport+1
			rfidic-get-message.sh RFID05026I "$ifxport"
		done
		rfidic-get-message.sh RFID05027I "$ifxport"
		echo  "$INFORMIXPORT	$ifxport/tcp			# Informix Server Port" >> /etc/services
		# Updating rfidic-env.sh
  		run_command sed "s,IFX_PORT_NUMBER=[0-9]*,IFX_PORT_NUMBER=$ifxport," $RFIDIC_HOME/bin/rfidic-env.sh > $RFIDIC_HOME/bin/rfidic-env.sh.temp
  		run_command mv -f  $RFIDIC_HOME/bin/rfidic-env.sh.temp $RFIDIC_HOME/bin/rfidic-env.sh
  		chown $RFIDIC_USER:$RFIDIC_GROUP $RFIDIC_HOME/bin/rfidic-env.sh
  		run_command chmod 750 ${RFIDIC_HOME}/bin/rfidic-env.sh
	fi 
}

setMQPort()
{
	while `grep -w $mqport/tcp /etc/services | grep -v '^#' >/dev/null`
	do
		rfidic-get-message.sh  RFID05021I  "$mqport"
		let mqport=mqport+1
		rfidic-get-message.sh  RFID05022I "$mqport"
	done
	rfidic-get-message.sh  RFID05023I "$mqport"
	echo  "mqm		$mqport/tcp			# MQ Series Port" >> /etc/services
}

temp_services=/tmp/rfidic-configPort-svcs.tmp
case "$1" in
	informix)
		setIFXPort
		;;
	mq)
		setMQPort
		MQ_LSR_PORT=$mqport
		export MQ_LSR_PORT
		;;
	clean)
		sed '/'$INFORMIXPORT'/d' /etc/services >| ${temp_services}
		mv -f ${temp_services} /etc/services
		sed '/mqm/d' /etc/services >| ${temp_services}
		mv -f ${temp_services} /etc/services
		chmod 644 /etc/services
		;;
	cleaninformix)
		sed '/'$INFORMIXPORT'/d' /etc/services >| ${temp_services}
		mv -f ${temp_services} /etc/services
		chmod 644 /etc/services
		;;
	cleanmq)
		sed '/mqm/d' /etc/services >| ${temp_services}
		mv -f ${temp_services} /etc/services
		chmod 644 /etc/services
		;;         
	*)
		# Usage
		. $RFIDIC_HOME/bin/rfidic-env.sh > /dev/null
		rfidic-get-message.sh RFID05081I "$0"
esac
