#! /bin/sh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

## utility to deploy the database using the metadata files
## usage: deployMetadata.sh [ -migrate ]
##############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
        . ${RFIDIC_HOME}/bin/rfidic-env.sh
else
        . ${SCRIPT_DIR}/rfidic-env.sh
fi

# print usage
usage(){
	 rfidic-get-message.sh RFID05085I "$0"        
}

checkWAS(){
# Checking WAS
serverStatus=`${WAS_HOME}/bin/serverStatus.sh $SERVERNAME | grep "The Application Server" | awk '{print($7)}'`
if [ "$serverStatus" = "STARTED" ];then
	if [ "$stop_was" != "true" ];then
    		promptUserWAS
	fi
	if [ "$stop_was" = "true" ];then
	      # Try to stop was
		if [ -n "$was_admin_user" ];then
			if [ -z "$was_admin_password" ];then
				rfidic-get-message.sh -noid RFID05057I "$was_admin_user: "
				stty -echo
				read was_admin_password
				stty echo
			fi
			${WAS_HOME}/bin/stopServer.sh $SERVERNAME -username $was_admin_user -password $was_admin_password
		else
			${WAS_HOME}/bin/stopServer.sh $SERVERNAME
		fi
	fi
	retcode=$?
	if [ ! "$retcode" = "0" ];then
		#echo "The WebSphere Application Server could not be stopped. Ensure that the server is stopped and then retry. Exiting..."
		rfidic-get-message.sh RFID05237I
	fi
fi
}

#### Main starts here #########
for item in $*
   do
     if [ "$item" = "-migrate" ];then
         migrate="-migrate";
     elif [ "$item" = "-force_drop_tables" ];then
         drop_tables=true;
     elif [ "$item" = "-force_stop_was" ];then
         stop_was=true;
     elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
          was_admin_user=`echo ${item#-was_admin_user=}`
     elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
          was_admin_password=`echo ${item#-was_admin_password=}`
     elif [ `expr match "$item" '-metadata_dir'` != 0 ];then
          METADATA_FILES_PATH=`echo ${item#-metadata_dir=}`
     else
         usage
         exit 1
     fi
done

ifxDb=0
oracleDb=1
db2Db=2

java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.server.ReadDatabaseType;
dbCode=$?

checkWAS
checkLogs

if [ -z "$migrate" ];then
   if [ "$drop_tables" != "true" ];then
        promptUser
   fi
fi

distributed $DB_HOST
db_dist=$?

java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect connect
conn=$?
if [ "$conn" = "0" ];then
	#echo "Connection to DB successful"
	rfidic-get-message.sh RFID05238I
	if [ "$drop_tables" = "true" -a -z "$migrate" ];then
	      # Just drop tables and recreate them if the database exists
	      migrate="-drop_tables"
	fi
else
	#echo "Connection to DB was not successful. Exiting deploy..."
	rfidic-get-message.sh RFID05239I
	exit
fi

if [ -z "$METADATA_FILES_PATH" ];then
	METADATA_FILES_PATH="$RFIDIC_HOME/etc"
fi
run_command java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME  com.ibm.rfidic.metadata.deploy.Deploy $migrate 

# the following command might fail if the current metadata doesn't match the default metadata
# therefore, don't check its return status
if [ "$migrate" != "-migrate" ]; then
	if [ "$dbCode" -eq "$ifxDb" ];then
		java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect update ${RFIDIC_HOME}/bin/Informix/rfidic_create_sample_schema.sql > /dev/null
	elif [ "$dbCode" -eq "$oracleDb" ];then
	  	java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect update $RFIDIC_HOME/bin/Oracle/rfidic_create_sample_schema.sql > /dev/null
	elif [ "$dbCode" -eq "$db2Db" ];then
	  	java -classpath $CLASSPATH -DRFIDIC_HOME=$RFIDIC_HOME com.ibm.rfidic.utils.install.DBConnect update $RFIDIC_HOME/bin/DB2/rfidic_create_sample_schema.sql > /dev/null
	else
	  #echo "Invalid DBMS type"
	  rfidic-get-message.sh RFID05230E
	  exit 1
	fi
fi
exit 0
