#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: rfidic-default-cfg.sh	
##   Description: Wrapper script to configure Informix, MQ, WAS.
##		
##
#############################################################################
# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
. ${SCRIPT_DIR}/rfidic-env.sh 

usage(){
	. ${RFIDIC_INSTALL_HOME}/bin/rfidic-env.sh > /dev/null
	rfidic-get-message.sh RFID05082I "$0"	
}

action="configure"
components="$DB_TYPE MQ WAS"

for item in $*
do
		if [ `echo $item | wc -c` = 2 ];then
			usage
			exit -1
		elif [ `expr match $item '-action='` != 0 ];then
			action=`echo ${item#-action=}`
			if [ "$action" = "unconfigure" ];then
				OPTION="-clean"
			elif [ "$action" = "configure" ];then
				OPTION=""
			else	
				usage
				exit -1
			fi
		elif [ `expr match "$item" '-components='` != 0 ];then
			components=`echo ${item#-components=}`
			components=`echo "$components" | tr "," "\n" | tr "[a-z]" "[A-Z]" | sort`
		elif [ `expr match "$item" '-installLocation='` != 0 ];then
			RFIDIC_HOME=`echo ${item#-installLocation=}`
		elif [ `expr match "$item" '-outFile='` != 0 ];then
			OUT=`echo ${item#-outFile=}`
		elif [ `expr match "$item" '-errFile='` != 0 ];then
			ERR=`echo ${item#-errFile=}`
		elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
                        was_admin_user=`echo ${item#-was_admin_user=}`
                elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
                        was_admin_password=`echo ${item#-was_admin_password=}`
		elif [ `expr match "$item" '-MQ_USER_PASSWORD'` != 0 ];then
                      MQ_USER_PASSWORD=`echo ${item#-MQ_USER_PASSWORD=}`
		elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
                        was_runas_user=`echo ${item#-was_runas_user=}`
                elif [ `expr match "$item" '-was_runas_group'` != 0 ];then
                        was_runas_group=`echo ${item#-was_runas_group=}`
                elif [ `expr match $item '-ifx_db_size='` != 0 ];then
                        ifx_db_size=`echo ${item#-ifx_db_size=}`
                elif [ `expr match $item '-ifx_dbspace_loc='` != 0 ];then
                        ifx_dbspace_loc=`echo ${item#-ifx_dbspace_loc=}`
                elif [ "$item" == "-force_drop_db" ];then
			drop_db=true
                        force_drop_db="-force_drop_db";
		else
			usage
			exit -1
		fi
done

echo_verbose "out = $OUT"
echo_verbose "err = $ERR"
if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
     	 rfidic-get-message.sh -noid RFID05060I "$was_admin_user"
       stty -echo
	 read was_admin_password
	 stty echo
	 echo
fi

configureMQ(){
if [ -d "$MQ_HOME" ]
then
	if [ "$action" = "configure" ]; then
        	rfidic-get-message.sh  RFID05063I
      	fi

	if [ "$action" = "unconfigure" ]; then
        	rfidic-get-message.sh  RFID05064I 
	fi

	if [ -n "$OUT" ]; then
			 if [ -n "$ERR" ];then
				 run_command ${RFIDIC_INSTALL_HOME}/bin/rfidic-mq-cfg.sh $OPTION 1> "$OUT" 2> "$ERR"
			 else
				 run_command ${RFIDIC_INSTALL_HOME}/bin/rfidic-mq-cfg.sh $OPTION 1> "$OUT" 2>&1
			 fi
	else
			 run_command ${RFIDIC_INSTALL_HOME}/bin/rfidic-mq-cfg.sh $OPTION
	fi
else
	rfidic-get-message.sh RFID05062E "$MQ_HOME"        
fi
return
}

configureInformix(){
if [ -d "$DBMS_HOME" ]
then

	if [ "$action" = "configure" ]
	then
        	rfidic-get-message.sh  RFID05065I
	fi
      	
	if [ "$action" = "unconfigure" ]
	then
        	rfidic-get-message.sh  RFID05066I	
	fi

	if [ "$drop_db" != "true" ];then
                promptUser
		force_drop_db="-force_drop_db"
        fi

	if [ "$OPTION" != "-clean" ];then
		if [ -z "$ifx_db_size" ];then
			ifx_db_size=smalldb
		fi
		IFX_OPTION="$force_drop_db -ifx_action=createdb -ifx_db_size=$ifx_db_size -ifx_dbspace_loc=$ifx_dbspace_loc"
	else
		IFX_OPTION="$force_drop_db $OPTION"
	fi
	if [ -n "$OUT" ];then
			 if [ -n "$ERR" ];then
				 run_command ${RFIDIC_INSTALL_HOME}/bin/rfidic-ifx-cfg.sh $IFX_OPTION 1> "$OUT" 2> "$ERR"				 
			 else
				 run_command ${RFIDIC_INSTALL_HOME}/bin/rfidic-ifx-cfg.sh $IFX_OPTION 1> "$OUT" 2>&1				 
			 fi
	else
			 run_command ${RFIDIC_INSTALL_HOME}/bin/rfidic-ifx-cfg.sh $IFX_OPTION
	fi
else
	
	rfidic-get-message.sh  RFID05067E "$DBMS_HOME"	
	exit -1
fi
return
}

configureWAS(){
if [ -d "$WAS_HOME" ]
then
	if [ "$action" = "configure" ] ;then
        	rfidic-get-message.sh  RFID05068I
      	fi
	if [ "$action" = "unconfigure" ] ;then
        	rfidic-get-message.sh  RFID05069I
	fi

	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        	credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
	fi
	if [ -n "$MQ_USER_PASSWORD" ];then
	        MQ_USER_PASSWORD="-MQ_USER_PASSWORD=$MQ_USER_PASSWORD"
	fi
	if [ -n "$was_runas_user" ];then
	        was_runas_user="-was_runas_user=$was_runas_user"
	fi

	if [ -n "$was_runas_group" ];then
        	was_runas_group="-was_runas_group=$was_runas_group"
	fi
	if [ -n "$OUT" ];then
			 if [ -n "$ERR" ];then
				 run_command ${RFIDIC_INSTALL_HOME}/bin/rfidic-was-cfg.sh $OPTION $credentials $MQ_USER_PASSWORD $was_runas_user $was_runas_group 1> "$OUT" 2> "$ERR"
			 else
				 run_command ${RFIDIC_INSTALL_HOME}/bin/rfidic-was-cfg.sh $OPTION $credentials $MQ_USER_PASSWORD $was_runas_user $was_runas_group 1> "$OUT" 2>&1
			 fi
	else
			 run_command ${RFIDIC_INSTALL_HOME}/bin/rfidic-was-cfg.sh $OPTION $credentials $MQ_USER_PASSWORD $was_runas_user $was_runas_group 
	fi
else

	rfidic-get-message.sh  RFID05070E "$WAS_HOME"
	
fi
return
}


export comp=`echo $components|sed "s/ /|/g"`
if [ "$action" = "configure" ]; then
       	rfidic-get-message.sh  RFID05061I "$comp"
fi
if [ "$action" = "unconfigure" ]; then
    	rfidic-get-message.sh  RFID05235I "$comp"
fi
for item in $components
do
case "$item" in
        INFORMIX)
		configureInformix
		;;
	  ORACLE)
		;;
	  DB2)
		;;
        MQ)
		configureMQ
		;;
        WAS)
		configureWAS
		;;
        *)	

		rfidic-get-message.sh RFID05059E "$item" 
esac
done
