#!/bin/sh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title:	rfidic-env.sh
##   Description: Sets the environment for other applications to use
##		
##
#############################################################################

# print output if the user selected the verbose option in a script
echo_verbose()
{
  if [ "$RFIDIC_VERBOSE" ]; then
     echo $*
  fi
}

# get CELLNAME and NODENAME from WAS installation. This might override defaults.
getActualWASConfig () {

   if [ ! -n "$WAS_PROFILE" ]; then
	  WAS_PROFILE=default
   fi
   
   WAS_CFG=${WAS_HOME}/profiles/${WAS_PROFILE}/config/cells
   echo_verbose WAS_PROFILE = $WAS_PROFILE
   echo_verbose CELLNAME = $CELLNAME
   echo_verbose NODENAME = $NODENAME
   echo_verbose SERVERNAME = $SERVERNAME
   echo_verbose WAS_PORT_NO = $WAS_PORT_NO
   if [ ! -d "$WAS_CFG" ];then
	if [ `ls ${WAS_HOME}/profiles | wc -w` = "1" ]; then
		WAS_PROFILE=`ls ${WAS_HOME}/profiles`
        	WAS_CFG=${WAS_HOME}/profiles/${WAS_PROFILE}/config/cells
		echo_verbose WAS_PROFILE = $WAS_PROFILE
   	else
    		rfidic-get-message.sh RFID05035E "$WAS_PROFILE"
		return 1
	fi
   fi
	  if [ ! -d $WAS_CFG/$CELLNAME ]; then
	  if [ `ls ${WAS_CFG}| wc -w` = "1" ]; then
		CELLNAME=`ls ${WAS_CFG}`
		echo_verbose CELLNAME = $CELLNAME
	  else
        rfidic-get-message.sh RFID05029E
		return 1
	  fi
	fi
	if [ ! -d $WAS_CFG/$CELLNAME/nodes/$NODENAME ];then
  	   if [ `ls ${WAS_CFG}/${CELLNAME}/nodes | wc -w` = "1" ]; then
		  NODENAME=`ls ${WAS_CFG}/${CELLNAME}/nodes`
          rfidic-get-message.sh RFID05031I "$NODENAME"
                
 	   else

          rfidic-get-message.sh RFID05032E
		  return 1
	   fi
	fi
	if [ ! -d $WAS_CFG/$CELLNAME/nodes/$NODENAME/servers/$SERVERNAME ]; then
	   if [ `ls ${WAS_CFG}/${CELLNAME}/nodes/${NODENAME}/servers | wc -w` = "1" ]; then
		  SERVERNAME=`ls ${WAS_CFG}/${CELLNAME}/nodes/${NODENAME}/servers`
          rfidic-get-message.sh RFID05033I "$SERVERNAME"
	   else

          rfidic-get-message.sh RFID05034E
		  return 1
	   fi
	fi
}

determineIP()
{
	if [ "$OS" = "AIX" ];then
		var1=`ifconfig -l | sed 's,lo.*,,g' | wc -w`
		if [ "$var1" -gt "1" ];then
			IP="127.0.0.1"
			rfidic-get-message.sh RFID05147W
		else
			IP=`host -n -t A $HOSTNAME | awk '{print($4)}'`
		fi
	elif [ "$OS" = "Linux" ];then
		var1=`netstat -i | grep -v "lo" | wc -l`
		# Ignoring first two lines (header)
		if [ "$var1" -gt "3" ];then
			IP="127.0.0.1"
			rfidic-get-message.sh RFID05147W
		else
			IP=`hostname -i`
		fi
	elif [ "$OS" = "SunOS" ];then
			var1=`netstat -i | grep -v "lo" | wc -l`
			# Ignoring first two lines (header)
			if [ "$var1" -gt "3" ];then
				IP="127.0.0.1"
				rfidic-get-message.sh RFID05147W
			else
				IP=`getent hosts $HOSTNAME | awk '{print($1)}'`
			fi
	fi
}

distributed(){
host=$1
determineIP
if [ "$host" = "$HOSTNAME" -o "$host" = "$HOSTNAMEFULL" -o "$host" = "$IP" ];then
	return 0
else 
	return 1
fi
}

version=v2.0

# determine where script was called from
script_location=`dirname $0 2>/dev/null`
if [ -z "$script_location" ];then
	script_location="."
fi

# determine RFIDIC_HOME
if  [ -f $script_location"/../etc/RFIDICServer.xml" ]
then
        RFIDIC_HOME="`( cd \"${script_location}"/.."\" && pwd )`"
fi
if  [ -n "$RFIDIC_HOME" ] 
then
	echo_verbose "RFIDIC_HOME= " $RFIDIC_HOME
else
	RFIDIC_HOME=/opt/ibm/WebSphere/RFIDIC$version
	echo_verbose "RFIDIC_HOME= " $RFIDIC_HOME
fi

if [ ! -d "$RFIDIC_HOME" ] 
then
# Just to spit out the 'cannot open directory' message in the language of the OS, 
# since messages cannot be translated without setting the environment.
 	file $RFIDIC_HOME
 	exit
fi

RFIDIC_INSTALL_HOME=$RFIDIC_HOME

# RFID IC user and group
if [ -z "$RFIDIC_USER" ];then 
	RFIDIC_USER=rfidic
	rfidic_user_password=rfidic123
fi
if [ -z "$RFIDIC_GROUP" ];then 
	RFIDIC_GROUP=rfidic
fi
if [ -z "$RFIDIC_HOME_DIR" ];then
	RFIDIC_HOME_DIR=~rfidic
fi


OS=`uname`
if [ "$OS" = "SunOS" ];then
	HOSTNAME=`hostname`
	HOSTNAMEFULL=`/usr/sbin/check-hostname | awk '{print($7)}'`
elif [ "$OS" = "Linux" ];then
	HOSTNAME=`hostname -s`
	HOSTNAMEFULL=`hostname -f`
elif [ "$OS" = "AIX" ];then
	HOSTNAME=`hostname -s`
	HOSTNAMEFULL=`hostname`
fi

# Determine distributed env
if [ -z "$MQ_HOST" ];then
	MQ_HOST=$HOSTNAMEFULL
fi

if [ -z "$DB_HOST" ];then
	DB_HOST=$HOSTNAMEFULL
fi

distributed $MQ_HOST
mq_dist=$?
export mq_dist

distributed $DB_HOST
db_dist=$?
export db_dist

#MQ Settings
if [ -z "$MQ_HOME" ];then
	MQ_HOME=/opt/mqm
fi
if [  -d "$MQ_HOME" ] 
then 
	echo_verbose "MQ =$MQ_HOME" 
else 
# Just to spit out the 'cannot open directory' message in the language of the OS, 
# since messages cannot be translated without setting the environment.
	if [ "$mq_dist" = "0" ];then
 		file $MQ_HOME
	fi
fi
if [ -z "$QUEUE_MANAGER" ];then 
	QUEUE_MANAGER=RFIDICv11.QUEUE.MANAGER
fi
if [ -z "$QUEUE_NAME" ];then 
	QUEUE_NAME=EPCEVENT
fi
if [ -z "$ALERTS_ENGINE_INPUT_QUEUE_NAME" ];then 
	ALERTS_ENGINE_INPUT_QUEUE_NAME=AlertsEngineInputQueue
fi
if [ -z "$MDM_CHANGE_NOTIF_QUEUE_NAME" ];then 
	MDM_CHANGE_NOTIF_QUEUE_NAME=MDMChangeNotification
fi
if [ -z "$AS2DELIVERY_QUEUE_NAME" ];then 
	AS2DELIVERY_QUEUE_NAME=AS2Delivery
fi
if [ -z "$AS2REQUEST_QUEUE_NAME" ];then 
	AS2REQUEST_QUEUE_NAME=AS2Request
fi
if [ -z "$AS2RESPONSE_QUEUE_NAME" ];then 
	AS2RESPONSE_QUEUE_NAME=AS2Response
fi
if [ -z "$MQ_LSR_PORT" ];then 
	MQ_LSR_PORT=1414
fi
if [ -z "$MQ_USER" ];then
	MQ_USER=${RFIDIC_USER}
fi
if [ -z "$MQ_USER_PASSWORD" ];then
	MQ_USER_PASSWORD=${rfidic_user_password}
fi

#### Database settings ######
if [ -z "$DB_TYPE" ];then
	DB_TYPE=INFORMIX
fi
if [ -z "$DBMS_DB_NAME" ];then
	DBMS_DB_NAME=rfidic
	export DBMS_DB_NAME
fi
if [ -z "$DBMS_ADMN_USER" ];then
	DBMS_ADMN_USER=informix
	export DBMS_ADMN_USER
fi
if [ -z "$DBMS_ADMN_PWD" ];then
	DBMS_ADMN_PWD=informix123
	export DBMS_ADMN_PWD
fi
if [ -z "$DBMS_HOME" ];then
	DBMS_HOME=/opt/IBM/informix
fi
if [ -z "$DBMS_SERVER" ];then
	DBMS_SERVER=IBMIFX_DSv11
	export DBMS_SERVER
fi

DBMS_HOME_LIB=$RFIDIC_INSTALL_HOME/bin/Informix/jdbc
DBMS_ALIAS=RFIDICInformixAlias

case $DB_TYPE in
	INFORMIX) 
			INFORMIXSERVER=$DBMS_SERVER
			export INFORMIXSERVER

			if [ -z "$DB_LOCALE" ];then
				DB_LOCALE=EN_US.utf8
				export DB_LOCALE
			fi
			if [ -z "$CLIENT_LOCALE" ];then
				CLIENT_LOCALE=EN_US.utf8
				export CLIENT_LOCALE
			fi
			if [ -z "$SERVER_LOCALE" ];then
				SERVER_LOCALE=EN_US.CP1252
				export SERVER_LOCALE
			fi
			if [ -z "$DBLANG" ];then
				DBLANG=EN_US.CP1252
				export DBLANG
			fi
			if [ -z "$INFORMIXPORT" ];then
				INFORMIXPORT=on_$INFORMIXSERVER
				export INFORMIXPORT
			fi
			if [ -z "$ONCONFIG" ];then
				ONCONFIG=onconfig.$INFORMIXSERVER
				export ONCONFIG
			fi
			IFX_PORT_NUMBER=1526
			export IFX_PORT_NUMBER

			INFORMIXDIR=$DBMS_HOME
			export INFORMIXDIR
			INFORMIXSQLHOSTS=$INFORMIXDIR/etc/sqlhosts
			export INFORMIXSQLHOSTS
			;;
	ORACLE)
			DBMS_ALIAS=RFIDICOracleAlias
			DBMS_HOME_LIB=$RFIDIC_INSTALL_HOME/bin/Oracle/jdbc
			ORACLE_GROUP=system			
			ORACLE_USER=oracle			
			ORACLE_HOME=$DBMS_HOME
			ORACLE_PORT_NUMBER=1521

			export ORACLE_PORT_NUMBER
			export ORACLE_GROUP
			export ORACLE_USER
			export ORACLE_HOME

			ORACLE_JDBC_URL=jdbc:oracle:thin:@${DB_HOST}:${ORACLE_PORT_NUMBER}:${DBMS_DB_NAME}
			;;
	DB2)
			DBMS_ALIAS=RFIDICDb2Alias
			DBMS_HOME_LIB=$RFIDIC_INSTALL_HOME/bin/DB2/jdbc
			DB2_SERVER=$DB_HOST
			DB2_GROUP=db2grp1
			DB2_INSTANCE=db2inst1
			DB2_PORT_NUMBER=50000

			export DB2_PORT_NUMBER
			export DB2_INSTANCE
			export DB2_GROUP
			export DB2_SERVER
			;;
	*)
			exit 1
			;;
esac

export DBMS_ALIAS
export DBMS_HOME_LIB
export DBMS_SERVER

if [ ! -d "$DBMS_HOME" ];then
# Just to spit out the 'cannot open directory' message in the language of the OS, 
# since messages cannot be translated without setting the environment.
	if [ "$db_dist" = "0" ];then
 		file $DBMS_HOME
		exit
	fi
fi

#WAS Settings
if [ -z "$WAS_HOME" ];then
	WAS_HOME=$RFIDIC_INSTALL_HOME/WASExpress/AppServer
if [ -d "$WAS_HOME" ] 
then
	echo_verbose "WAS =" $WAS_HOME
elif [ -d "/opt/IBM/WebSphere/AppServer" ]
then
	WAS_HOME="/opt/IBM/WebSphere/AppServer"
	echo_verbose "WAS=  "$WAS_HOME
else 
# Just to spit out the 'cannot open directory' message in the language of the OS, 
# since messages cannot be translated without setting the environment.
 	file $WAS_HOME
fi
fi

#Global variables to be used for WAS configuration and installation
#These must be replaced with the values derived from the user input / WAS installation

if [ -z "$WAS_PROFILE" ];then
	WAS_PROFILE=default
fi
if [ -z "$RFIDIC_BUS_NAME" ];then
	RFIDIC_BUS_NAME=RFIDICBus
fi
if [ -z "$SERVERNAME" ];then
	SERVERNAME=server1
fi
if [ -z "$WAS_PORT_NO" ];then
	WAS_PORT_NO=9080
fi
if [ -z "$NODENAME" ];then
	NODENAME="$HOSTNAME"Node01
fi
if [ -z "$CELLNAME" ];then
	CELLNAME="$HOSTNAME"Node01Cell
fi

#Application info.
if [ -z "$RFAPP_NAME" ];then
	RFAPP_NAME=com.ibm.rfidic.webEAR
fi
if [ -z "$RFAPP_LOCATION" ];then
	RFAPP_LOCATION=$RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.web.ear
fi
if [ -z "$UIAPP_NAME" ];then
	UIAPP_NAME=com.ibm.rfidic.web.uiEAR
fi
if [ -z "$UIAPP_LOCATION" ];then
	UIAPP_LOCATION=$RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.web.ui.ear
fi
if [ -z "$RFIDIC_ALERTS_APP_NAME" ];then
	RFIDIC_ALERTS_APP_NAME=com.ibm.rfidic.web.alertsEAR
fi
if [ -z "$RFIDIC_ALERTS_APP_LOCATION" ];then
	RFIDIC_ALERTS_APP_LOCATION=$RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.web.alerts.ear
fi
if [ -z "$RFIDIC_PUB_MSGSER_APP_NAME" ];then
	RFIDIC_PUB_MSGSER_APP_NAME=com.ibm.rfidic.ejb.auditEAR
fi
if [ -z "$RFIDIC_PUB_MSGSER_APP_LOC" ];then
	RFIDIC_PUB_MSGSER_APP_LOC=$RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.ejb.audit.ear
fi
if [ -z "$SIDAPP_LOCATION" ];then
	SIDAPP_LOCATION=$RFIDIC_HOME/bin/WAS/ears/com.ibm.rfidic.web.enterprise.serialid.ear
fi
if [ -z "$SIDAPP_NAME" ];then
	SIDAPP_NAME=com.ibm.rfidic.web.enterprise.serialidEAR
fi

# Java Settings
if [ -z "$JAVA_HOME" ];then
if [ -d $WAS_HOME ]; then
	JAVA_HOME=$WAS_HOME/java
elif [ -d "$INFORMIXDIR" ];then
	JAVA_HOME=$INFORMXDIR/extend/krakatoa/jre
fi
fi
export JAVA_HOME

if [ "$mq_dist" = "0" ];then
	MQ_INSTALL_PATH=$MQ_HOME
	MQ_LIB_PATH=$MQ_HOME/java/lib
else
	MQ_INSTALL_PATH=$WAS_HOME/lib/WMQ
	MQ_LIB_PATH=$WAS_HOME/lib/WMQ/java/lib
fi

export MQ_INSTALL_PATH
export MQ_LIB_PATH

# Set PATH and CLASSPATH only if already not set
if [ -n  "$pathdone" ]; then
	echo_verbose "PATH = "$PATH
       echo_verbose "CLASSPATH=" $CLASSPATH
else
	PATH=.:$JAVA_HOME/bin:$RFIDIC_INSTALL_HOME/bin:$MQ_HOME/bin:$DBMS_HOME/bin:$WAS_HOME/bin:$PATH
	export PATH

	#CLASSPATH Setting
	for i in $RFIDIC_INSTALL_HOME/lib/*.jar 
	do
		CLASSPATH=$CLASSPATH:$i
	done
	CLASSPATH=$CLASSPATH:$MQ_LIB_PATH/com.ibm.mqjms.jar:$MQ_LIB_PATH/com.ibm.mq.jar:$WAS_HOME/lib/j2ee.jar
	if [ "$DB_TYPE" = "INFORMIX" ];then
		CLASSPATH=$CLASSPATH:$RFIDIC_INSTALL_HOME/bin/Informix/jdbc/ifxjdbcx.jar:$RFIDIC_INSTALL_HOME/bin/Informix/jdbc/ifxjdbc.jar
	elif [ "$DB_TYPE" = "ORACLE" ];then
		CLASSPATH=$CLASSPATH:$RFIDIC_INSTALL_HOME/bin/Oracle/jdbc/ojdbc14.jar
	elif [ "$DB_TYPE" = "DB2" ];then
		CLASSPATH=$CLASSPATH:$RFIDIC_INSTALL_HOME/bin/DB2/jdbc/db2jcc.jar:$RFIDIC_INSTALL_HOME/bin/DB2/jdbc/db2jcc_javax.jar:$RFIDIC_INSTALL_HOME/bin/DB2/jdbc/db2jcc_license_cu.jar:$RFIDIC_INSTALL_HOME/bin/DB2/jdbc/db2jcc_license_cisuz.jar
	fi
	export CLASSPATH
	#The path currently points to the main WAS installation.
	#If it needs to point to the target profile, add the path to the /profiles/default/bin folder here
	#export PATH=$WAS_HOME/profiles/default/bin:$PATH
	pathdone=yes
	export pathdone
fi

getActualWASConfig

RFIDIC_JAVA="${RFIDIC_HOME}/WASExpress/AppServer/java/jre/bin/java -DRFIDIC_HOME=$RFIDIC_HOME"

# runs a command and terminates if the exit code is non-zero
run_command ()
{
	command="$*"
	"$@"
	retcode=$?
	if [ "$retcode" -ne 0 ]
	then	
		rfidic-get-message.sh RFID05138E "$command"

		exit $retcode
	fi
}

# check if log directory exists and create it otherwise
checkLogs ()
{
if [ ! -d $RFIDIC_HOME/logs ]; then
  mkdir -p $RFIDIC_HOME/logs
fi
}

if [ "$RFIDIC_NOPROMPT" != "true" ] && [ "$RFIDIC_NOPROMPT" != "TRUE" ] && [ -z "$drop_tables" ];then
	drop_tables=false
	stop_db=false
	stop_was=false
else
	drop_tables=true
	stop_db=true
	stop_was=true
fi

promptUser ()
{
    while [ 1 ];do
#	echo -n "The database will be dropped. Are you sure you want to continue (y/n):"
	rfidic-get-message.sh -n RFID05001U
	read input
	if [ "$input" = "y" ] || [ "$input" = "Y" ];then
		drop_tables=true
		return
	elif [ "$input" = "n" ] || [ "$input" = "N" ];then
		rfidic-get-message.sh -noid RFID05002U
		exit 1
	else
		rfidic-get-message.sh -noid RFID05003U
	fi
    done
}

promptUserDBStop()
{
while [ 1 ];do
	#echo "The database will be stopped. Are you sure you want to continue (y/n):"
	rfidic-get-message.sh -n RFID05005U
	read input
	if [ "$input" = "y" ] || [ "$input" = "Y" ];then
		stop_db=true
		return
	elif [ "$input" = "n" ] || [ "$input" = "N" ];then
		rfidic-get-message.sh -noid RFID05002U
		exit 1
	else
		rfidic-get-message.sh -noid RFID05003U
	fi
    done
}

promptUserWAS()
{
while [ 1 ];do
	#echo "The application server will be stopped. Are you sure you want to continue (y/n):"
	rfidic-get-message.sh -n RFID05236I
	read input
	if [ "$input" = "y" ] || [ "$input" = "Y" ];then
		stop_was=true
		return
	elif [ "$input" = "n" ] || [ "$input" = "N" ];then
		rfidic-get-message.sh -noid RFID05002U
		exit 1
	else
		rfidic-get-message.sh -noid RFID05003U
	fi
done
}

appendClassPathWithWASJars()
{
if [ -n  "$wascpathdone" ]; then
       echo_verbose "CLASSPATH=" $CLASSPATH
else
	CLASSPATH=$CLASSPATH:$WAS_HOME/lib/j2ee.jar:$WAS_HOME/lib/webservices.jar:$WAS_HOME/installedChannels/channel.http.jar:$WAS_HOME/installedChannels/channel.tcp.jar:$WAS_HOME/installedChannels/channel.ssl.jar:$WAS_HOME/lib/naming.jar
	CLASSPATH=$CLASSPATH:$WAS_HOME/runtimes/com.ibm.ws.webservices.thinclient_6.1.0.jar
	export CLASSPATH
	wascpathdone=yes
	export wascpathdone
fi
}

sslWASSettings()
{
   echo "-Djava.protocol.handler.pkgs=com.ibm.net.ssl.internal.www.protocol -Djavax.net.ssl.trustStore="$WAS_HOME/profiles/$WAS_PROFILE/etc/DummyClientTrustFile.jks" -Djavax.net.ssl.trustStorePassword=WebAS -Djavax.net.ssl.keyStore="$WAS_HOME/profiles/$WAS_PROFILE/etc/DummyClientTrustFile.jks" -Djavax.net.ssl.keyStorePassword=WebAS -Djavax.net.ssl.keyStoreType=JKS -Djavax.net.ssl.trustStoreType=JKS -Djavax.net.ssl.protocol=SSL"
}


runUserCommand()
{
	user=$1
	shift
	command="$*"
	if [ "$OS" = "SunOS" ];then
		/bin/su - ${user} -c "${command}"
		retcode=$?
	elif [ "$OS" = "AIX" ];then
		/bin/su - ${user} "-c ${command}"
		retcode=$?
	else
		/bin/su - -c "${command}" ${user}
		retcode=$?
	fi
return $retcode
}
