#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title:rfidic-ifx-cfg.sh	
##   Description: Configures  or unconfigures the embedded Informix database. 
##        During configuration, it generates the vital data needed to run the 
##        Informix server, installs Informix Node Blade, deploys metadata.
##		
##
##   Usage: rfidic-ifx-cfg.sh
##          rfidic-ifx-cfg.sh -clean"
##          rfidic-ifx-cfg.sh -ifx_action=createdb -ifx_db_size=smalldb"
##          rfidic-ifx-cfg.sh -ifx_action=createdb -ifx_db_size=mediumdb 
##			      -ifx_dbspace_loc=<dir location for db files>"
##          rfidic-ifx-cfg.sh -ifx_action=createdb -ifx_db_size=largedb 
##			      -ifx_dbspace_loc=<dir location for db files>"
##          rfidic-ifx-cfg.sh -ifx_action=extenddbspace 
##			      -ifx_dbspace_name=<dbspace name> 
##			      -ifx_chunk_loc=<dir location>
##			      -ifx_chunk_name=<chunk file name>
##			      -ifx_chunk_size=<db size as 5000000K for 5 GB>"
##          rfidic-ifx-cfg.sh -ifx_action=adddbspace 
##			      -ifx_dbspace_name=<dbspace name>
##			      -ifx_chunk_loc=<dir location>
##			      -ifx_chunk_name=<chunk file name>
##			      -ifx_chunk_size=<db size as 5000000K for 5 GB>"
##	    rfidic-ifx-cfg.sh -ifx_action=addtempspace 
##			      -ifx_dbspace_name=<dbspace name>
##			      -ifx_chunk_loc=<dir location>
##			      -ifx_chunk_name=<chunk file name>
##			      -ifx_chunk_size=<db size as 5000000K for 5 GB>"
##
##
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
. $SCRIPT_DIR/rfidic-env.sh 

Updatefiles()
{
#update the /etc/services file 
	$RFIDIC_HOME/bin/configPort.sh informix
#create online.log if it does not exist
	if [ ! -f $INFORMIXDIR/online.log ];then
		touch $INFORMIXDIR/online.log
	fi
#check permissions of online.log
	run_command chown informix:informix $INFORMIXDIR/online.log
	run_command chmod 664 $INFORMIXDIR/online.log
	mkdir /INFORMIXTMP
	DBTEMP=/INFORMIXTMP
#Prepare the onconfig and the sqlhosts file for the SERVER
	run_command sed 's,$INFORMIXSERVER,'$INFORMIXSERVER',g' $RFIDIC_HOME/bin/sqlhosts.seed > $RFIDIC_HOME/bin/sqlhosts.temp
	run_command sed 's,$IP,'$DB_HOST',g' $RFIDIC_HOME/bin/sqlhosts.temp > $RFIDIC_HOME/bin/sqlhosts.tmp
	run_command sed 's,$INFORMIXPORT,'$INFORMIXPORT',g' $RFIDIC_HOME/bin/sqlhosts.tmp > $RFIDIC_HOME/bin/sqlhosts
	echo_verbose "db_size is: $db_size"
	if [ "$largedb_flag" -ne 1 ]
	then
		run_command sed 's,$INFORMIXSERVER,'$INFORMIXSERVER',g' $RFIDIC_HOME/bin/onconfig.seed > $RFIDIC_HOME/bin/onconfig.tmp1
		run_command sed 's,$INFORMIXDIR,'$INFORMIXDIR',g' $RFIDIC_HOME/bin/onconfig.tmp1 > $RFIDIC_HOME/bin/onconfig.tmp
		if [ "$OS" = "AIX" ];then
			run_command sed 's,0x44000000L,0x40000000L,g' $RFIDIC_HOME/bin/onconfig.tmp > $RFIDIC_HOME/bin/$ONCONFIG
		else
			run_command cp -rf --reply=yes $RFIDIC_HOME/bin/onconfig.tmp $RFIDIC_HOME/bin/$ONCONFIG
		fi
	else
		echo_verbose "DBSPACEDIR : $DBSPACEDIR"
		run_command sed 's,$INFORMIXSERVER,'$INFORMIXSERVER',g' $RFIDIC_HOME/bin/onconfig_lg.seed > $RFIDIC_HOME/bin/onconfig_lg.tmp1
		run_command sed 's,$DBSPACEDIR,'$DBSPACEDIR',g' $RFIDIC_HOME/bin/onconfig_lg.tmp1 > $RFIDIC_HOME/bin/onconfig_lg.tmp2
		run_command sed 's,$INFORMIXDIR,'$INFORMIXDIR',g' $RFIDIC_HOME/bin/onconfig_lg.tmp2 > $RFIDIC_HOME/bin/onconfig_lg.tmp
		if [ "$OS" = "AIX" ];then
			run_command sed 's,0x44000000L,0x40000000L,g' $RFIDIC_HOME/bin/onconfig_lg.tmp > $RFIDIC_HOME/bin/$ONCONFIG
		else
			run_command cp -rf --reply=yes $RFIDIC_HOME/bin/onconfig_lg.tmp $RFIDIC_HOME/bin/$ONCONFIG
		fi
	fi

#move the files to etc directory of Informix install
	run_command chmod 660 $RFIDIC_HOME/bin/sqlhosts
	run_command chmod 660 $RFIDIC_HOME/bin/$ONCONFIG
	run_command chown informix:informix $RFIDIC_HOME/bin/sqlhosts
	run_command chown informix:informix $RFIDIC_HOME/bin/$ONCONFIG

	run_command mv -f $RFIDIC_HOME/bin/sqlhosts $INFORMIXDIR/etc
	run_command mv -f $RFIDIC_HOME/bin/$ONCONFIG $INFORMIXDIR/etc
	
#remove temporary files
	if [ "$largedb_flag" -ne 1 ]
	then
		run_command rm -rf $RFIDIC_HOME/bin/onconfig.tmp
		run_command rm -rf $RFIDIC_HOME/bin/onconfig.tmp1
	else
		run_command rm -rf $RFIDIC_HOME/bin/onconfig_lg.tmp1
		run_command rm -rf $RFIDIC_HOME/bin/onconfig_lg.tmp2
		run_command rm -rf $RFIDIC_HOME/bin/onconfig_lg.tmp
	fi
	run_command rm -rf $RFIDIC_HOME/bin/sqlhosts.tmp
	run_command rm -rf $RFIDIC_HOME/bin/sqlhosts.temp

}

CleanIFX()
{
	rfidic-get-message.sh RFID05001I
	rfidic-get-message.sh RFID05002I
	onmode -ky
#	export ONCONFIG=onconfig.$INFORMIXSERVER
	ROOTPATH=`grep ROOTPATH $INFORMIXDIR/etc/$ONCONFIG | awk '{print $2}'`
	ROOTPATHDIR=`dirname "$ROOTPATH"`
	$RFIDIC_HOME/bin/configPort.sh cleaninformix
	rm -rf /INFORMIXTMP
	rm -rf $INFORMIXDIR/extend/Node.1.0
	rm -f $ROOTPATH
	rm -f $INFORMIXDIR/etc/sqlhosts
	rm -f $INFORMIXDIR/etc/onconfig.$INFORMIXSERVER
}

Smalldbcreate() 
{
if [ ! -d $INFORMIXDIR/dbspaces ]
then
	run_command mkdir $INFORMIXDIR/dbspaces
fi
	cd $INFORMIXDIR/dbspaces
	run_command touch online_root
	run_command chmod 660 online_root
	cd ..
	run_command chown -R informix dbspaces
	run_command chgrp -R informix dbspaces
	run_command onmode -ky
	run_command oninit -iy
	checkSysDatabases

	run_command onmode -ky
}

Epilogue()
{
# copy the Node Blade Files to Informix Install directory 

if [ "$OS" = "AIX" ];then
	run_command cp -R -Eforce $RFIDIC_HOME/bin/Informix/AIX/Node.1.0 $INFORMIXDIR/extend
else
	run_command cp -rf --reply=yes $RFIDIC_HOME/bin/Informix/LNX/Node.1.0 $INFORMIXDIR/extend
fi
run_command chown -R informix:informix $INFORMIXDIR/extend/Node.1.0
run_command chmod -R 755 $INFORMIXDIR/extend/Node.1.0
run_command oninit -y

#create sbspace
if [ "$largedb_flag" -eq 0 ]
then
	run_command touch $INFORMIXDIR/dbspaces/chunk
	run_command chmod 660 $INFORMIXDIR/dbspaces/chunk
	run_command chown informix:informix $INFORMIXDIR/dbspaces/chunk
	run_command onspaces -c -S sbspace -p $INFORMIXDIR/dbspaces/chunk -o 0 -s 502400
fi

# Adding rfidic user to informix group
run_command /usr/sbin/usermod -G ${RFIDIC_GROUP},informix ${RFIDIC_USER}
# If mqm present
/usr/sbin/usermod -G ${RFIDIC_GROUP},mqm,informix ${RFIDIC_USER}

sleep 5
# Generating RFIDICServer.xml 

export PORTNUMBER=`grep $INFORMIXPORT /etc/services|awk '{print(substr($2,1,index($2,"/")-1))}'`
if [ "$OS" = "AIX" ];then
	command="{\ns%<Portnumber>*.*</Portnumber>%<Portnumber>$PORTNUMBER</Portnumber>%g\n}"
	run_command echo $command > $RFIDIC_HOME/etc/RFIDICServer.xml.sed
	run_command sed -f $RFIDIC_HOME/etc/RFIDICServer.xml.sed $RFIDIC_HOME/etc/RFIDICServer.xml > $RFIDIC_HOME/etc/RFIDICServer.xml.temp
	run_command rm -f $RFIDIC_HOME/etc/RFIDICServer.xml.sed
else
	run_command sed 's,<Portnumber>*.*</Portnumber>,<Portnumber>'$PORTNUMBER'</Portnumber>,g' $RFIDIC_HOME/etc/RFIDICServer.xml > $RFIDIC_HOME/etc/RFIDICServer.xml.temp
fi
run_command mv -f $RFIDIC_HOME/etc/RFIDICServer.xml.temp $RFIDIC_HOME/etc/RFIDICServer.xml
chown $RFIDIC_USER:$RFIDIC_GROUP $RFIDIC_HOME/etc/RFIDICServer.xml
run_command chmod 640 ${RFIDIC_HOME}/etc/RFIDICServer.xml

# Create DB if it does not exist
run_command runUserCommand ${RFIDIC_USER} dbaccess -e - ${RFIDIC_HOME}/bin/Informix/create_db.sql;
distributed $DB_HOST
db_dist=$?

# Run Deploy tool only for a non-distributed environment
# determine JAVA_HOME

if [ "$db_dist" = "0" ];then
	# Giving connect permissions to RFIDIC user
	run_command runUserCommand ${RFIDIC_USER} dbaccess << EOF
	connect to '${DBMS_DB_NAME}';
	grant connect to '${RFIDIC_USER}';
	commit;
EOF

	if  [ -d "$JAVA_HOME" ]
	then
       	run_command runUserCommand ${RFIDIC_USER} $RFIDIC_HOME/bin/deployMetadata.sh -force_drop_tables -force_stop_was $credentials
	else
        	rfidic-get-message.sh RFID05003E
	fi
fi
}

Usage()
{	
	rfidic-get-message.sh RFID05080I "$0"
}

Createlargedb()
{
if [ ! -d $DBSPACEDIR/rfidic_dbspaces ]
then
	run_command mkdir $DBSPACEDIR/rfidic_dbspaces
fi
	cd $DBSPACEDIR/rfidic_dbspaces
	run_command touch online_root rfidic_dbsp rfidic_indsp rfidic_physlog rfidic_virtlog
	run_command chmod 660 online_root rfidic_dbsp rfidic_indsp rfidic_physlog rfidic_virtlog
	cd ..
	run_command chown -R informix rfidic_dbspaces
	run_command chgrp -R informix rfidic_dbspaces
	cd rfidic_dbspaces

	run_command onmode -ky
	run_command oninit -iy
	sleep 10
	checkSysDatabases
	# Creating a db space for data
	run_command onspaces -c -d rfidicDbsp -p $DBSPACEDIR/rfidic_dbspaces/rfidic_dbsp -o 0 -s $DBSPACESIZE
	if [ $? -ne 0 ]
	then
		rfidic-get-message.sh RFID05004E "$DBSPACEDIR/rfidic_dbspaces/rfidic_dbsp" "$DBSPACESIZE"
		exit 1
	fi
	# Creating a db space for indexes
	run_command onspaces -c -d rfidicIndsp -p $DBSPACEDIR/rfidic_dbspaces/rfidic_indsp -o 0 -s  $INDEXSPACESIZE
	if [ $? -ne 0 ]
	then
		rfidic-get-message.sh RFID05004E "$DBSPACEDIR/rfidic_dbspaces/rfidic_indsp" "$INDEXSPACESIZE"
		exit 1
	fi

	# Creating a physical log space
	run_command onspaces -c -d rfidicPhyslog -p $DBSPACEDIR/rfidic_dbspaces/rfidic_physlog -o 0 -s $PHYSLOGSIZE 
	if [ $? -ne 0 ]
	then
		rfidic-get-message.sh RFID05005E "$DBSPACEDIR/rfidic_dbspaces/rfidic_physlog" "$PHYSLOGSIZE"
		exit 1
	fi

	# Creating a virtual log space
	onspaces -c -d rfidicVirtlog -p $DBSPACEDIR/rfidic_dbspaces/rfidic_virtlog -o 0 -s  $VIRTLOGSIZE
	if [ $? -ne 0 ]
	then
		rfidic-get-message.sh RFID05006E "$DBSPACEDIR/rfidic_dbspaces/rfidic_virtlog" "$VIRTLOGSIZE"
		exit 1
	fi

	# Next create the virtual log files in the virtual log space
	for i in 1 2 3 4 5 6 7 8 9
	do
		run_command onparams -a -s $VIRTLOGFLSZ -d rfidicVirtlog
	done
	if [ $? -ne 0 ]
	then
		rfidic-get-message.sh RFID05007E rfidic_virtlog
		exit 1
	fi

	# Create a chunk for sbspace
	cd $DBSPACEDIR/rfidic_dbspaces
	run_command touch chunk
	run_command chmod 660 chunk
	run_command chown informix:informix chunk
	run_command onspaces -c -S sbspace -p $DBSPACEDIR/rfidic_dbspaces/chunk -o 0 -s 502400

	run_command onmode -ky
}

Checkparams()
{
	# First check if a location to create the db spaces is provided
	if [ -z "$DBSPACEDIR" ] || [ ! -d "$DBSPACEDIR" ]
	then
		rfidic-get-message.sh RFID05008E
		Usage
		exit 1
	fi

	# Next check if the directory provided has greater than 30GB in free space
	if [ "$OS" = "AIX" ];then
		freespace=`df -k $DBSPACEDIR | awk '{print $3}'`
	else
		freespace=`df -k $DBSPACEDIR | awk '{print $4}'`
	fi
	freespace=`echo $freespace | awk '{print $2}'`
	echo "REQDSPACE = $REQDSPACE"
	echo "freespace = $freespace"

	if [ "$freespace" -le "$REQDSPACE" ]
	then
		rfidic-get-message.sh RFID05009E "$REQDSPACE"
		exit 1
	fi
}

Checkparams_addchunk()
{
	# check if correct number of params passed
	if [ $# -ne 5 ] 
	then
		rfidic-get-message.sh RFID05010E 5 $#
		Usage
		exit 1
	fi
	if [ -z "$DBDIR" ] || [ -z "$DBSPACE_NM" ] || [ -z "$CHUNK_NM" ] || [ -z "$CHUNK_SZ" ]
	then
		Usage
		exit 1
	fi
	# check to see if directory to create chunk exists and is writable
	if [ ! -d "$DBDIR" ] || [ ! -w "$DBDIR" ]
	then
		rfidic-get-message.sh RFID05011E "$DBDIR" "$CHUNK_NM"
		Usage
		exit 1
	fi
}

Addchunk()
{
	# check to see if the dbspace name passed exists.
	run_command onstat -d | grep $DBSPACE_NM > /dev/null
	if [ $? -ne  0 ]
	then
		rfidic-get-message.sh RFID05012E "$DBSPACE_NM"
		exit 1
	fi

	run_command touch $DBDIR/$CHUNK_NM
	run_command chmod 660 $DBDIR/$CHUNK_NM
	run_command chown informix:informix $DBDIR/$CHUNK_NM

	echo_verbose "onspaces -a $DBSPACE_NM -p $DBDIR/$CHUNK_NM -o 0 -s $CHUNK_SZ"
	onspaces -a $DBSPACE_NM -p $DBDIR/$CHUNK_NM -o 0 -s $CHUNK_SZ
	if [ $? -ne 0 ]
	then
		rfidic-get-message.sh RFID05013E
		exit 1
	fi
}

Creatdbspace()
{

# Check if informix is up and running
	run_command onstat > /dev/null
	if [ $? -ne 0 ]; then
		rfidic-get-message.sh RFID05014E
		exit 1
	fi
	run_command touch $DBDIR/$CHUNK_NM
	run_command chmod 660 $DBDIR/$CHUNK_NM
	run_command chown informix:informix $DBDIR/$CHUNK_NM

	onspaces -c -d $DBSPACE_NM -p $DBDIR/$CHUNK_NM -o 0 -s $CHUNK_SZ
	if [ $? -ne 0 ]
	then
		rfidic-get-message.sh RFID05004E "$DBDIR/$CHUNK_NM" "$CHUNK_SZ"
		exit 1
	fi
}

Creattempspace()
{

# Check if informix is up and running
	onstat > /dev/null
	if [ $? -ne 0 ]; then
		rfidic-get-message.sh RFID05014E
		exit 1
	fi

	run_command touch $DBDIR/$CHUNK_NM
	run_command chmod 660 $DBDIR/$CHUNK_NM
	run_command chown informix:informix $DBDIR/$CHUNK_NM
	echo $DBSPACE_NM
	onspaces -c -d $DBSPACE_NM -t -p $DBDIR/$CHUNK_NM -o 0 -s $CHUNK_SZ
	if [ $? -ne 0 ]
	then
		rfidic-get-message.sh RFID05004E "$DBDIR/$CHUNK_NM" "$CHUNK_SZ"
		exit 1
	fi

	if [ -f $INFORMIXDIR/etc/$ONCONFIG.tmp ];then
		rm -f $INFORMIXDIR/etc/$ONCONFIG.tmp
	fi

	run_command sed 's,tempdbs,'$DBSPACE_NM',g' $INFORMIXDIR/etc/$ONCONFIG > $INFORMIXDIR/etc/$ONCONFIG.temp
	run_command mv -f $INFORMIXDIR/etc/$ONCONFIG.temp $INFORMIXDIR/etc/$ONCONFIG
	
	run_command chmod 660 $INFORMIXDIR/etc/$ONCONFIG
	run_command chown informix:informix $INFORMIXDIR/etc/$ONCONFIG	
}

#
#Main Starts here
#
# Check to see if parameters passed correctly
ParseParams(){
	for item in $*
	do
		if [ `echo $item | wc -c` = 2 ];then
			Usage
			exit 1
		elif [ `expr match $item '-clean'` != 0 ];then
			action=clean
		elif [ `expr match $item '-ifx_action='` != 0 ];then
			action=`echo ${item#-ifx_action=}`
		elif [ `expr match $item '-ifx_db_size='` != 0 ];then
			db_size=`echo ${item#-ifx_db_size=}`
		elif [ `expr match $item '-ifx_dbspace_loc='` != 0 ];then
                        DBSPACEDIR=`echo ${item#-ifx_dbspace_loc=}`
		elif [ `expr match $item '-ifx_dbspace_name='` != 0 ];then
                        DBSPACE_NM=`echo ${item#-ifx_dbspace_name=}`
		elif [ `expr match $item '-ifx_chunk_loc='` != 0 ];then
                        DBDIR=`echo ${item#-ifx_chunk_loc=}`
		elif [ `expr match $item '-ifx_chunk_name='` != 0 ];then
                        CHUNK_NM=`echo ${item#-ifx_chunk_name=}`
		elif [ `expr match $item '-ifx_chunk_size='` != 0 ];then
                        CHUNK_SZ=`echo ${item#-ifx_chunk_size=}`
		elif [ $item = "-force_drop_db" ];then
                        drop_db=true
		elif [ `expr match "$item" '-was_admin_user'` != 0 ];then
          		was_admin_user=`echo ${item#-was_admin_user=}`
     		elif [ `expr match "$item" '-was_admin_password'` != 0 ];then
          		was_admin_password=`echo ${item#-was_admin_password=}`
		else
			Usage			
			exit 1
		fi
	done
}

#To check that system databases has been created
checkSysDatabases(){

sysdatabase=0
until [ $sysdatabase -gt 0 ]
do

sysmaster=`onstat -m |grep -c "'sysmaster' database built successfully."`

sysutils=`onstat -m |grep -c "'sysutils' database built successfully."`

sysuser=`onstat -m |grep -c "'sysuser' database built successfully."`

	if [ $sysuser -eq 0 ] 
	then
	   sysuser=`onstat -m |grep -c "'sysuser' database already exists."`		
	
	fi

	if [ $sysmaster -gt 0 ]
	then
		if [ $sysutils -gt 0 ]
		then
			if [ $sysuser -gt 0 ]
			then	
				sysdatabase=1
			fi
		fi
	fi


done
rfidic-get-message.sh RFID05079I

}
ParseParams $*
if [ -z "$action" ];then
	action="createdb"
fi
if [ -z "$db_size" ];then
	db_size="smalldb"
fi
largedb_flag=0

if [ -n "$was_admin_user" -a -z "$was_admin_password" ];then
       rfidic-get-message.sh -noid RFID05057I "$was_admin_user: "
	stty -echo
	read was_admin_password
	stty echo
fi

if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
	credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
fi

#Getting IP value from rfidic_env.sh file
determineIP
ip=`echo $IP | tr -s " "`

case "$action" in
	createdb)
		if [ "$drop_db" != "true" ];then
			promptUser
		fi
		case "$db_size" in
			smalldb)
				rfidic-get-message.sh RFID05078I
				rfidic-get-message.sh RFID05073I
				Updatefiles
				rfidic-get-message.sh RFID05071I
				Smalldbcreate
				rfidic-get-message.sh RFID05072I
				Epilogue
				;;
			mediumdb)
				REQDSPACE=14457280
				Checkparams
				largedb_flag=1
				rfidic-get-message.sh RFID05078I
				rfidic-get-message.sh RFID05073I
				Updatefiles
				DBSPACESIZE="4000000K"
				INDEXSPACESIZE="1500000K"
				PHYSLOGSIZE="2000000K"
				VIRTLOGSIZE="5000000K"
				VIRTLOGFLSZ="499900"
				rfidic-get-message.sh RFID05074I
				Createlargedb
				rfidic-get-message.sh RFID05072I
				Epilogue
				;;
			largedb)
				REQDSPACE=77428800
				Checkparams
				rfidic-get-message.sh RFID05078I
				largedb_flag=1
				rfidic-get-message.sh RFID05073I
				Updatefiles
				DBSPACESIZE="25000000K"
				INDEXSPACESIZE="15000000K"
				PHYSLOGSIZE="2000000K"
				VIRTLOGSIZE="5000000K"
				VIRTLOGFLSZ="499990"
				rfidic-get-message.sh RFID05075I
				Createlargedb
				rfidic-get-message.sh RFID05072I
				Epilogue
				;;
			*)
				Usage
				;;
		esac
		;;
	clean)
		if [ "$drop_db" != "true" ];then
			promptUser
		fi
		rfidic-get-message.sh RFID05078I
		rfidic-get-message.sh RFID05076I
		CleanIFX
		;;
	extenddbspace)
		Checkparams_addchunk $*
		rfidic-get-message.sh RFID05078I
		Addchunk
		;;
	adddbspace)
		Checkparams_addchunk $*
		rfidic-get-message.sh RFID05078I
		Creatdbspace
		;;
	addtempspace)
		Checkparams_addchunk $*
		rfidic-get-message.sh RFID05078I
		Creattempspace
		;;
	*)
		Usage
		;;
esac
