#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2006
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: rfidic-mq-cfg.sh	
##   Description: Configures MQ Manager and Queues
##		
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
. ${SCRIPT_DIR}/rfidic-env.sh 

if [ "$DB_TYPE" = "INFORMIX" ];then
	  run_command /usr/sbin/usermod -G ${RFIDIC_GROUP},mqm,informix ${RFIDIC_USER}
elif [ "$DB_TYPE" = "ORACLE" ];then
	  run_command /usr/sbin/usermod -G ${RFIDIC_GROUP},mqm,${ORACLE_GROUP} ${RFIDIC_USER}
elif [ "$DB_TYPE" = "DB2" ];then
	  run_command /usr/sbin/usermod -G ${RFIDIC_GROUP},mqm,${DB2_GROUP} ${RFIDIC_USER}
else
	  run_command /usr/sbin/usermod -G ${RFIDIC_GROUP},mqm ${RFIDIC_USER}
fi	

#Getting IP value from rfidic_env.sh file
determineIP
ip=`echo $IP | tr -s " "`

if [ "$1" = "-clean" ]; then
   rfidic-get-message.sh RFID05015I
   endmqbrk -m ${QUEUE_MANAGER}

   runUserCommand ${MQ_USER} endmqlsr -m ${QUEUE_MANAGER}
   . $RFIDIC_INSTALL_HOME/bin/configPort.sh cleanmq
   runUserCommand ${MQ_USER} endmqm -w ${QUEUE_MANAGER}
   runUserCommand ${MQ_USER} dltmqm ${QUEUE_MANAGER}
else
   . $RFIDIC_INSTALL_HOME/bin/configPort.sh mq
   run_command runUserCommand ${MQ_USER} crtmqm -q ${QUEUE_MANAGER}
   run_command runUserCommand ${MQ_USER} strmqm ${QUEUE_MANAGER}
   run_command runUserCommand ${MQ_USER} runmqlsr -t tcp -m ${QUEUE_MANAGER} -p ${MQ_LSR_PORT} &



   run_command runUserCommand ${MQ_USER} runmqsc ${QUEUE_MANAGER} << EOF
	DEFINE QLOCAL ('${QUEUE_NAME}') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Input Queue of the capture interface') SHARE REPLACE
        DEFINE QLOCAL ('$ALERTS_ENGINE_INPUT_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Input queue for alerts processing engine') SHARE REPLACE
        DEFINE QLOCAL ('$MDM_CHANGE_NOTIF_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Output Queue for RFIDIC MDM Change Notifications') SHARE REPLACE
	DEFINE QLOCAL ('$AS2DELIVERY_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Delivery Queue for AS2 subscription queries') SHARE REPLACE
	DEFINE QLOCAL ('$AS2REQUEST_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Input Queue for AS2 query requests') SHARE REPLACE
	DEFINE QLOCAL ('$AS2RESPONSE_QUEUE_NAME') DEFPSIST(YES) LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE) DESCR('Output Queue for AS2 synchronous query results') SHARE REPLACE
	DEFINE CHANNEL(SYSTEM.ADMIN.SVRCONN) chltype(svrconn) TRPTYPE(TCP) mcauser('${MQ_USER}')
	START CHANNEL(SYSTEM.ADMIN.SVRCONN)
	DEFINE CHANNEL('RFIDICCHANNEL') chltype(RCVR) TRPTYPE(TCP)
	START CHANNEL('RFIDICCHANNEL')
EOF
#To enable publish/subscribe
	run_command runUserCommand ${MQ_USER} runmqsc ${QUEUE_MANAGER} < ${MQ_HOME}/java/bin/MQJMS_PSQ.mqsc
	# starting hte broker
	run_command runUserCommand ${MQ_USER} strmqbrk -m ${QUEUE_MANAGER}


  # Updating RFIDICServer.xml  
  run_command sed "s,<QueueManagerName>*.*</QueueManagerName>,<QueueManagerName>$HOSTNAMEFULL:$MQ_LSR_PORT</QueueManagerName>," $RFIDIC_HOME/etc/RFIDICServer.xml > $RFIDIC_HOME/etc/RFIDICServer.xml.temp
  run_command mv -f $RFIDIC_HOME/etc/RFIDICServer.xml.temp $RFIDIC_HOME/etc/RFIDICServer.xml
  chown $RFIDIC_USER:$RFIDIC_GROUP $RFIDIC_HOME/etc/RFIDICServer.xml
  run_command chmod 640 ${RFIDIC_HOME}/etc/RFIDICServer.xml

  # Updating rfidic-env.sh
  run_command sed "s,MQ_LSR_PORT=[0-9]*,MQ_LSR_PORT=$MQ_LSR_PORT," $RFIDIC_HOME/bin/rfidic-env.sh > $RFIDIC_HOME/bin/rfidic-env.sh.temp
  run_command mv -f  $RFIDIC_HOME/bin/rfidic-env.sh.temp $RFIDIC_HOME/bin/rfidic-env.sh
  chown $RFIDIC_USER:$RFIDIC_GROUP $RFIDIC_HOME/bin/rfidic-env.sh
  run_command chmod 750 ${RFIDIC_HOME}/bin/rfidic-env.sh
fi
exit 0
