#!/bin/sh
#############################################################################
## Licensed Material - Property of IBM
##
## (C) Copyright IBM Corp. 2006, 2008 - All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or disclosure
## restricted by GSA ADP Schedule Contract with IBM Corp.
## 
## (C) Copyright IBM Corp. and other(s) 2006, 2008  
## 
## The following sample of source code ("Sample Code") is owned by 
## International Business Machines Corporation or one of its subsidiaries 
## ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
## modify, and distribute the Sample Code in any form without payment to IBM, 
## for the purpose of assisting you in the development of your applications.
##
## The Sample Code is provided to you on an "AS IS" basis, without warranty of 
## any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
## IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
## MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
## not allow for the exclusion or limitation of implied warranties, so the 
## above limitations or exclusions may not apply to you. IBM shall not be 
## liable for any damages you suffer as a result of using, copying, modifying 
## or distributing the Sample Code, even if IBM has been advised of the 
## possibility of such damages.
##
##   Title: alertsUtility.sh
##   Description: Optionally compiles and Updates alerts subscriptions
##   Usage: alertsUtility.sh [-nocompile|-help]"
##
#############################################################################

# include the RFIDIC environment settings
SCRIPT_DIR=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
        . $RFIDIC_HOME/bin/rfidic-env.sh
else
        . $SCRIPT_DIR/rfidic-env.sh
fi

# print usage
usage(){
	# echo "Usage: $0 [-nocompile|-help]"
        rfidic-get-message.sh -noid RFID07503U "$0"
	exit 1
}

# print usage
createJar(){
	run_command find . -name "*.java" -exec javac {} \;
	
	if [ -r $JAR ]
	then
		run_command rm $JAR
	fi
	
	run_command touch $JAR
	run_command find . -name "*.class" -exec jar uvf $JAR {} \;
	run_command find . -name "*.xml" -exec jar uvf $JAR {} \;
}

#### Main starts here #########
MODE="compile"
if [ $# -gt 2 ]
then
   usage
   exit 1
else
   for item in $*
   do
     if [ "$item" = "-nocompile" ];then
		MODE="nocompile";
     elif [ `expr match "$item" '-was_runas_user'` != 0 ];then
          was_runas_user=`echo ${item#-was_runas_user=}`
     elif [ "$item" = "-help" ];then
         usage
     else
         usage
     fi
  done
fi

script_location=`dirname $0 2>/dev/null`
if [ -z "$script_location" ];then
        script_location="."
fi

source_dir="`( cd \"${script_location}"/../src"\" && pwd )`"
echo "source_dir=$source_dir"
cd $source_dir

JAR=$RFIDIC_HOME/lib/com.ibm.rfidic.alerts.samples.jar
# ibm-jaxrpc-client.jar is for WebSphere 6.0.2 and com.ibm.ws.webservices.thinclient_6.1.0.jar is for other versions
CLASSPATH=$JAR:$CLASSPATH:$JAVA_HOME/../runtimes/com.ibm.ws.webservices.thinclient_6.1.0.jar:$JAVA_HOME/../runtimes/ibm-jaxrpc-client.jar:.

# jars needed for the Relational adapter classes. rsaexternal.jaris for WebSphere 6.0.2 and com.ibm.ws.runtime_6.1.0.jar is for other versions
CLASSPATH=$CLASSPATH:$JAVA_HOME/../lib/rsaexternal.jar:$JAVA_HOME/../plugins/com.ibm.ws.runtime_6.1.0.jar
if [ $MODE = "compile" ]
then
	createJar
fi
HOST=http://$IP:9080
run_command java -classpath $CLASSPATH com.ibm.rfidic.alerts.utils.AlertsUtilityDelete $HOST
run_command ${RFIDIC_HOME}/bin/stopRFIDIC.sh -components=WAS
if [ -z "$was_runas_user" ];then
	run_command startServer.sh $SERVERNAME
else
	runUserCommand ${was_runas_user} $WAS_HOME/bin/startServer.sh ${SERVERNAME}
fi
run_command java -classpath $CLASSPATH com.ibm.rfidic.alerts.utils.AlertsUtility $HOST $JAR