/**
 * Licensed Material - Property of IBM
 * (C) Copyright IBM Corp. 2006, 2008 - All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * 
 * (C) Copyright IBM Corp. and other(s) 2006, 2008  
 * 
 * The following sample of source code ("Sample Code") is owned by 
 * International Business Machines Corporation or one of its subsidiaries 
 * ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
 * modify, and distribute the Sample Code in any form without payment to IBM, 
 * for the purpose of assisting you in the development of your applications.
 *
 * The Sample Code is provided to you on an "AS IS" basis, without warranty of 
 * any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
 * IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
 * not allow for the exclusion or limitation of implied warranties, so the 
 * above limitations or exclusions may not apply to you. IBM shall not be 
 * liable for any damages you suffer as a result of using, copying, modifying 
 * or distributing the Sample Code, even if IBM has been advised of the 
 * possibility of such damages.
 */
package com.ibm.rfidic.alerts.utils;

import java.io.File;
import java.io.FileWriter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

import com.ibm.rfidic.ws.clients.WebServiceManager;
import com.ibm.rfidic.ws.clients.alerts.Alert;
import com.ibm.rfidic.ws.clients.alerts.DeliveryMethod;
import com.ibm.rfidic.ws.clients.alerts.NotificationConfiguration;
import com.ibm.rfidic.ws.clients.alerts.Parameter;
import com.ibm.rfidic.ws.clients.alerts.ParameterValue;
import com.ibm.rfidic.ws.clients.alerts.Subscription;
import com.ibm.rfidic.ws.clients.alerts.VoidHandler;
import com.ibm.rfidic.ws.clients.classloader.ClassloaderRegistry_PortType;
import com.ibm.rfidic.ws.clients.classloader.Jar;

/* The Alerts Utility provides functions that helps a Solution Developer
 * call functions to display, register and unregister Jars, Alerts, 
 * Delivery Methods, Notification Configurations and Subscriptions.  
 */
public class AlertsUtilityDelete
{
  private WebServiceManager mgr = null;

  /* The constructor does not need to be altered by the Soluton Developer. */
  public AlertsUtilityDelete (String serverURL, String propertiesFile)
  {
    try
    {
      /* Create a file for our credentials if one does not exist already. */
      String fileName = "credential.properties";
      File file = new File(fileName); 
      if (file.exists() == false)
      {
        FileWriter fw = new FileWriter(fileName);
        fw.write("userName=user\n");
        fw.write("password=password\n");
        fw.flush();
        fw.close();
      }
      
      mgr =  new WebServiceManager(serverURL,fileName);
    }
    catch(Exception e)
    {
       e.printStackTrace();
    }
  }
  
  /* The main function calls all the Web Serive methods to display, register and 
   * unregister Jars, Alerts, Delivery Methods, Notification Configurations and
   * Subscriptions.
   * The Solution Developer should only need to alter the contents of the main 
   * method to complete the actions they want to perform.  
   */
  public static void main (String arg[]) throws Exception
  {
    /*-----------------------------------------------------------------*/  
    /* 1. Initialize variables used to register artifacts etc.         */
    /*-----------------------------------------------------------------*/
    String rfidicUrl = "http://localhost:9080"; // URL of the RFIDIC server
    if (arg.length == 1)
    {
        rfidicUrl=arg[0];
    }
    System.out.println("rfidicUrl = "+rfidicUrl);

    /* Edit these boolean to change behavior. */
    boolean jars            = true;
    boolean alerts          = true;
    boolean deliveryMethods = true;
    boolean notifConfigs    = true;
    boolean subscriptions   = true;
    
    /*-----------------------------------------------------------------*/
    /* 2. Create a utility object.                                     */
    /*-----------------------------------------------------------------*/  
    AlertsUtilityDelete util =  new AlertsUtilityDelete(rfidicUrl,"credential.properties");
  
    /*-----------------------------------------------------------------*/
    /* 3. These functions can be used for displaying, registering and  */
    /*    unregistering Jar files.                                     */
    /*    Warning: If one or more Jar files are unregistered then WAS  */
    /*    needs to be stopped and restarted for the unregistration to  */
    /*    take effect.                                                 */
    /*-----------------------------------------------------------------*/

    if (jars == true)
    {
      util.displayJars();
      util.unregisterAllJars();
    }

    /*-----------------------------------------------------------------*/
    /* 4. These functions can be used to register and unregister       */
    /*    Alerts.                                                      */
    /*-----------------------------------------------------------------*/
    if (alerts == true)
    {
      util.displayAlerts();
      util.unregisterAllAlerts();
    }
    
    /*-----------------------------------------------------------------*/
    /* 5. These functions can be used to display, register and         */
    /*    unregister Delivery Methods.                                 */
    /*-----------------------------------------------------------------*/
    if (deliveryMethods == true)
    {
      util.displayDeliveryMethods();
      util.unregisterAllDeliveryMethods();
    }

    /*-----------------------------------------------------------------*/
    /* 6. These functions can be used to display, register and         */
    /*    unregister Notification Configurations.                      */
    /*-----------------------------------------------------------------*/
    if (notifConfigs == true)
    {
      util.displayNotificationConfigurations();
      util.unregisterAllNotifications();
    }
    
    /*-----------------------------------------------------------------*/
    /* 7. These functions can be used to display, register and         */
    /*    unregister Subscriptions.                                    */
    /*-----------------------------------------------------------------*/
    if (subscriptions == true)
    {
      util.displaySubscriptions();
      util.unregisterAllSubscriptions();
    }
  }
  
  /*------------------------------------------------------------------------------------------------*/
  /* Methods below this point should not need to be changed.                                        */                         
  /*------------------------------------------------------------------------------------------------*/
  
  private void displayJars() throws Exception
  {
    System.out.println("\n\nJars:");
    System.out.println("=======");
    
    ClassloaderRegistry_PortType classLoaderRegistry = mgr.getClassloaderRegistry();
    Jar[] jarList = classLoaderRegistry.listJars().getJarList();
    for (int i=0; i< jarList.length; i++)
    {
      System.out.println("Jar :: " + i + "::" + jarList[i].getJarName());
    }
  }
  
  private void unregisterAllJars () throws Exception
  {
    ClassloaderRegistry_PortType classLoaderRegistry = mgr.getClassloaderRegistry();
    
    Jar[] jarLst = classLoaderRegistry.listJars().getJarList();
    for (int i=0; i< jarLst.length; i++)
    {
      System.out.println("Unregistering jar :: "+jarLst[i].getJarName());
      classLoaderRegistry.removeJar(jarLst[i].getJarName());
    } 
    System.out.println("All jars unregistered.");
    System.out.println("You will have to restart WAS for the unregistration to take effect.");
  }

  private void displayAlerts()throws Exception
  {
    System.out.println("\n\nAlerts:");
    System.out.println("=======");
      
    final Alert[] alerts = mgr.getAlertsRegistry().getAll(new VoidHandler());
    if (alerts != null)
    {
      final List list = new ArrayList(Arrays.asList(alerts));
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final Alert alert = (Alert) iterator.next();
        System.out.println("id: " + alert.getId() + ", class name: " + alert.getClassName());
      }
    }
  }
  
  private void unregisterAllAlerts()throws Exception 
  {
    final Alert[] alerts = mgr.getAlertsRegistry().getAll(new VoidHandler());
    if (alerts != null)
    {
      final List list = new ArrayList(Arrays.asList(alerts));
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final Alert alert = (Alert) iterator.next();
        System.out.println("Unregistering alert ::: id: " + alert.getId() + ", class name: " + alert.getClassName());
        mgr.getAlertsRegistry().delete(alert.getId());
      }
    }
    System.out.println("All alerts unregistered.");
  }
  
  private void displayDeliveryMethods()throws Exception 
  {
    System.out.println("\n\nDelivery methods:");
    System.out.println("=================");
      
    final DeliveryMethod[] deliveryMethods = mgr.getDeliveryMethodsRegistry().getAll(new VoidHandler());
    if (deliveryMethods != null)
    {
      final List list = new ArrayList(Arrays.asList(deliveryMethods));
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final DeliveryMethod deliveryMethod = (DeliveryMethod) iterator.next();
        System.out.println("id: " + deliveryMethod.getId() + ", class name: " + deliveryMethod.getClassName());
      }
    }
  }

  private void unregisterAllDeliveryMethods () throws Exception 
  {
    final DeliveryMethod[] deliveryMethods = mgr.getDeliveryMethodsRegistry().getAll(new VoidHandler());
    if (deliveryMethods != null)
    {
      for (int i = 0; i < deliveryMethods.length; i++)
      {
        final DeliveryMethod delMethod = deliveryMethods[i];
        System.out.println("Unregistering delivery method ::: id: " + delMethod.getId() + ", class name: " + delMethod.getClassName());
        mgr.getDeliveryMethodsRegistry().delete(delMethod.getId());
      }
    }
    System.out.println("All delivery methods unregistered.");
  }
  
  private void displayNotificationConfigurations() throws Exception
  {
    System.out.println("\n\nNotification configurations:");
    System.out.println("============================");
    
    final NotificationConfiguration[] notificationConfigurations = mgr.getNotificationConfigurationsRegistry().getAll(new VoidHandler());
    if (notificationConfigurations != null)
    {
      final List list = new ArrayList(Arrays.asList(notificationConfigurations));

      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final NotificationConfiguration notificationConfiguration = (NotificationConfiguration) iterator.next();
        System.out.println("id: " + notificationConfiguration.getId() + ", class name: "
                           + notificationConfiguration.getClassName());
        System.out.println("XML:\n" + notificationConfiguration.getXmlContent());

        final Parameter[] parameters = notificationConfiguration.getParameters();
        if (parameters != null)
        {
          for (int i = 0; i < parameters.length; i++)
          {
            System.out.println("Parameter " + (i + 1) + ":");
            System.out.println("  Name: " + parameters[i].getName());
            System.out.println("  Type: " + parameters[i].getType());
          }
        }
      }
    }
  } 
  
  private void unregisterAllNotifications() throws Exception 
  {
    final NotificationConfiguration[] notificationConfigurations = mgr.getNotificationConfigurationsRegistry().getAll(new VoidHandler());
    if (notificationConfigurations != null)
    {
      final List list = new ArrayList(Arrays.asList(notificationConfigurations));

      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final NotificationConfiguration nc = (NotificationConfiguration) iterator.next();
        System.out.println("Unregistering notification config ::: id: " + nc.getId() + ", name: " + nc.getName());
        mgr.getNotificationConfigurationsRegistry().delete(nc.getId());
      }
    }
    System.out.println("All notification configurations unregistered.");
  }
  
  private void displaySubscriptions() throws Exception 
  {
    final Subscription[] subscriptions = mgr.getSubscriptionsRegistry().getAll(new VoidHandler());
    System.out.println("\n\nSubscriptions:");
    System.out.println("==============");
    if (subscriptions != null)
    {
      final List list = new ArrayList(Arrays.asList(subscriptions));
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final Subscription subscription = (Subscription) iterator.next();
        System.out.println("\nid: " + subscription.getId() + ", name: " + subscription.getName() + ", subscriber: "
            + subscription.getSubscriber() + ", alert id: " + subscription.getAlertId()
            + ", notification configuration id: " + subscription.getNotificationConfigurationId());

        final ParameterValue[] alertParameterValues = subscription.getAlertValues();
        if (alertParameterValues != null)
        {
          System.out.println("Alert parameter values:");
          System.out.println("-----------------------");
          for (int i = 0; i < alertParameterValues.length; i++)
          {
            System.out.println("Value " + (i + 1) + ":");
            System.out.println("  Name: " + alertParameterValues[i].getParameterName());
            System.out.println("  Value: " + alertParameterValues[i].getValue());
          }
        }

        final ParameterValue[] notificationConfigurationParameterValues = 
           subscription.getNotificationConfigurationValues();
         
        if (notificationConfigurationParameterValues != null)
        {
          System.out.println("Notification configuration parameter values:");
          System.out.println("--------------------------------------------");
          for (int i = 0; i < notificationConfigurationParameterValues.length; i++)
          {
            System.out.println("Value " + (i + 1) + ":");
            System.out.println("  Name: " + notificationConfigurationParameterValues[i].getParameterName());
            System.out.println("  Value: " + notificationConfigurationParameterValues[i].getValue());
          }
        }
      }
    }
  }

  private void unregisterAllSubscriptions() throws Exception
  {
    final Subscription[] subscriptions = mgr.getSubscriptionsRegistry().getAll(new VoidHandler());
    if (subscriptions != null)
    {
      final List list = new ArrayList(Arrays.asList(subscriptions));
        
      for (Iterator iterator = list.iterator(); iterator.hasNext();)
      {
        final Subscription sub = (Subscription) iterator.next();
        System.out.println("Unregistering subscriptions ::: id: " + sub.getId() + ", name: " + sub.getName());
        mgr.getSubscriptionsRegistry().delete(sub.getId()); 
      }
    }
    System.out.println("All subscriptions unregistered.");
  }
}