/**
 * Licensed Material - Property of IBM
 * (C) Copyright IBM Corp. 2006, 2008 - All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * 
 * (C) Copyright IBM Corp. and other(s) 2006, 2008  
 * 
 * The following sample of source code ("Sample Code") is owned by 
 * International Business Machines Corporation or one of its subsidiaries 
 * ("IBM") and is copyrighted and licensed, not sold. You may use, copy, 
 * modify, and distribute the Sample Code in any form without payment to IBM, 
 * for the purpose of assisting you in the development of your applications.
 *
 * The Sample Code is provided to you on an "AS IS" basis, without warranty of 
 * any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER EXPRESS OR 
 * IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Some jurisdictions do 
 * not allow for the exclusion or limitation of implied warranties, so the 
 * above limitations or exclusions may not apply to you. IBM shall not be 
 * liable for any damages you suffer as a result of using, copying, modifying 
 * or distributing the Sample Code, even if IBM has been advised of the 
 * possibility of such damages.
 */ 
package com.ibm.rfidic.audit.sample;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Enumeration;

import javax.jms.JMSException;
import javax.jms.MapMessage;
import javax.jms.TextMessage;

/**
 * Bean implementation class for Enterprise Bean: com.ibm.rfidic.audit.sample.AuditEventReader
 */
public class AuditEventReaderBean
	implements
		javax.ejb.MessageDrivenBean,
		javax.jms.MessageListener {

	private javax.ejb.MessageDrivenContext fMessageDrivenCtx;

	/**
	 * getMessageDrivenContext
	 */
	public javax.ejb.MessageDrivenContext getMessageDrivenContext() {
		return fMessageDrivenCtx;
	}

	/**
	 * setMessageDrivenContext
	 */
	public void setMessageDrivenContext(javax.ejb.MessageDrivenContext ctx) {
		fMessageDrivenCtx = ctx;
	}

	/**
	 * ejbCreate
	 */
	public void ejbCreate() {
	}

	/**
	 * onMessage
	 */
	public void onMessage(javax.jms.Message msg) {
		if (msg instanceof MapMessage){
			System.out.println("Received map message");
			MapMessage msg1 = (MapMessage) msg;
			try {
				// Print out the map names in the MapMessage 
				System.out.println("Map names in the map mesage:");
				for (Enumeration e = msg1.getMapNames(); e.hasMoreElements();)
					System.out.println(e.nextElement().toString());
				System.out.println("Property names in the map mesage:");
				// Print out all the property names in the MapMessage
				for (Enumeration e = msg1.getPropertyNames(); e.hasMoreElements();)
					System.out.println(e.nextElement().toString());
				//	TODO: Forward the received message to business logic for processing...
			} catch (JMSException e) {
				e.printStackTrace();
			}
		} else if (msg instanceof TextMessage) 
		{
			TextMessage textMsg = (TextMessage)msg;
			try 
			{
				System.out.println("Received text message : "+textMsg.getText());
				String path = System.getProperty("RFIDIC_HOME") + File.separator + "samples" + File.separator + "audit" + File.separator + "msg" + msg.hashCode() + ".xml";
				FileWriter writer = new FileWriter(path);
				writer.write(textMsg.getText());
				writer.close();
				// TODO: Forward the received message to business logic for processing...
			} 
			catch (JMSException x) 
			{
				x.printStackTrace();
			} 
			catch (IOException e) 
			{
				e.printStackTrace();
			}
		}
		else
			System.out.println("Received message is neither a text message nor a map message");
			return;
	}

	/**
	 * ejbRemove
	 */
	public void ejbRemove() {
	}
}
